# Nasheq E.R.P. Standardized A.P.I.s python integrations

## Quick Guide
Below are the steps on how to get the web app up and running

1.	Install it:
```bash
    pip install nashbanksync
```
2.	View get started documentation:
```bash
    https://nashbanksuite.readme.io/v1.2.0/docs
```
3.	Start Coding